@@ -6,7 +6,7 @@ if TYPE_CHECKING:
     from hgraph._types._scalar_value import ScalarValue
 
 
-__all__ = ('ScalarValueBuilder',)
+__all__ = ("ScalarValueBuilder",)
 
 
 class ScalarValueBuilder(Builder["ScalarValue"]):
@@ -16,4 +16,4 @@ class ScalarValueBuilder(Builder["ScalarValue"]):
         raise NotImplementedError()
 
     def release_instance(self, item: "ScalarValue"):
-        raise NotImplementedError()
\ No newline at end of file
+        raise NotImplementedError()
