@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
-from hgraph._impl._builder._node_builder import PythonBaseNodeBuilder, PythonNodeBuilder
+from hgraph._impl._builder._node_builder import PythonBaseNodeBuilder
 
 if TYPE_CHECKING:
     from hgraph._runtime._node import Node
@@ -26,4 +26,4 @@ class PythonNodeImplNodeBuilder(PythonBaseNodeBuilder):
         return self._build_inputs_and_outputs(node)
 
     def release_instance(self, item: "Node"):
-        """Nothing to do"""
\ No newline at end of file
+        """Nothing to do"""
