@@ -3,7 +3,8 @@ import operator
 from collections import deque
 from typing import Mapping, Any, Callable, cast, Iterable, Sequence
 
-from hgraph import TS, SCALAR
+from hgraph._types._ts_type import TS
+from hgraph._types._scalar_types import SCALAR
 
 from hgraph._runtime._lifecycle import start_guard, stop_guard
 from hgraph._builder._graph_builder import GraphBuilder
