@@ -1,7 +1,6 @@
 from dataclasses import dataclass
 from pathlib import Path
 
-
 __all__ = ("SourceCodeDetails",)
 
 
@@ -11,4 +10,7 @@ class SourceCodeDetails:
     start_line: int
 
     def __str__(self):
-        return f"{str(self.file)}: {self.start_line}"
+        return f"{str(self.file)}:{self.start_line}"
+
+    def __lt__(self, other):
+        return str(self) < str(other)
